local _, addon = ...
TomCatsToursConfig.name = "TomCat's Tours"
InterfaceOptions_AddCategory(TomCatsToursConfig)
TomCatsToursConfig_SlashCommands.name = "Slash Commands"
TomCatsToursConfig_SlashCommands.parent = "TomCat's Tours"
InterfaceOptions_AddCategory(TomCatsToursConfig_SlashCommands)

local slashCommandHandlers = { }
local components = { }

local function handleSlashCommand(msg)
    if (msg) then
        if (msg == "") then
            InterfaceOptionsFrame_OpenToCategory(TomCatsToursConfig)
            --todo: Remove the redundant call if Blizzard ever fixes this
            InterfaceOptionsFrame_OpenToCategory(TomCatsToursConfig)
        else
            local func = slashCommandHandlers[string.upper(msg)]
            if (not func) then
                InterfaceOptionsFrame_OpenToCategory(TomCatsToursConfig_SlashCommands)
                --todo: Remove the redundant call if Blizzard ever fixes this
                InterfaceOptionsFrame_OpenToCategory(TomCatsToursConfig_SlashCommands)
            else
                func()
            end
        end
    end
end

SLASH_TOMCATS1 = "/TOMCATS"
SlashCmdList["TOMCATS"] = handleSlashCommand

local slashCommandsHtmlHead = "<html>\n<body>\n<h1>Slash Commands</h1>\n<br />\n"
local slashCommandHtmlTemplate = "<h3>%s:</h3>\n<p>/TOMCATS %s</p>\n<br />\n"
local slashCommandsHtmlFoot = "</body>\n</html>"

TomCats = {}

local function refreshInterfaceControlPanels()
    local slashCommandsHtml = slashCommandsHtmlHead
    local infoText = "Installed Components:\n|cffffffff"
    slashCommandsHtml = slashCommandsHtml .. format(slashCommandHtmlTemplate, "Open the TomCat's Tours Control Panel", "")
    for i, component in ipairs(components) do
        if (component.slashCommands) then
            for _, slashCommand in ipairs(component.slashCommands) do
                slashCommandsHtml = slashCommandsHtml .. format(slashCommandHtmlTemplate, slashCommand.desc, string.upper(slashCommand.command))
            end
        end
        infoText = infoText .. "   " .. component.name .. " (v" .. component.version .. ")"
        if (i ~= #components) then
            infoText = infoText .. "\n"
        end
    end
    infoText = infoText .. "|r"
    TomCatsToursConfigInstalledComponents:SetText(infoText)
    slashCommandsHtml = slashCommandsHtml .. slashCommandsHtmlFoot
    TomCatsToursConfig_SlashCommands.html:SetText(slashCommandsHtml)
end

function TomCats:Register(componentInfo)
    if (componentInfo) then
        if (componentInfo.slashCommands) then
            for _, slashCommand in ipairs(componentInfo.slashCommands) do
                slashCommandHandlers[string.upper(slashCommand.command)] = slashCommand.func
            end
        end
        table.insert(components, componentInfo)
        refreshInterfaceControlPanels()
    end
end

refreshInterfaceControlPanels()
